--[[
---------------------------------------------------------------------------
Remote Train Control Program for Windows

© Copyright 2021 by Mark DiVecchio

	This file is part of Remote Train Control.

	Remote Train Control is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Remote Train Control is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Remote Train Control.  If not, see <http://www.gnu.org/licenses/>.

 Home Page : http://www.silogic.com/trains/RTC_Running.html
---------------------------------------------------------------------------]]
-- Semicolons are not required in Lua code
title = "Layout4 WB Block Occupancy Test"
require([[defines]]);
require([[functions]]);
--[[
When using this module, all variables (including functions!) must be declared through 
a regular assignment (even assigning nil will do) in a strict scope before being used 
anywhere or assigned to inside a nested scope.
https://github.com/lua-stdlib/strict
]]
local _ENV = require 'std.strict' (_G)	-- strict.lua will detect undeclared global variables

local ErrCount = 0;
local Layout4;
-- OCC is any value greater than zero
local OCC = 1;  -- Occupied
local PauseOn = false;
local StepTime = 3;

--[[---------------------------------------------------------------------------------------]]
function setup(Engine, TIU)
	print("setup() Running");
	-- Instrumented Layout 4
	Layout4 = require([[Layout4]]);		-- All of the details about the Layout
if (Layout4.LLLoop == true) then
	print("Balloon Loop");
	else
	print("Point-to-Point");
	end;	
--
	print([[Run "Layout4 APB Master.lua" in PC windows #1 (don't set any block occupied)]]);
	print("Run this Script in a PC window other than #1");
	ClearButton(Engine, TIU);			-- clear all program flags
--[=[
	-- start in Aliquippa Block
	print("Start in the Aliquippa Block, heading toward College Block - setup occupancy flags for start");
	SetEvent(1, BLOCK_OCCUPANCY_EVENT, ALIQUIPPA_BLOCK, OCC, 0);	-- set next block occupancy
	SetOccupancy(ALIQUIPPA_BLOCK, 1);	-- set occupancy flag
--]=]
---[=[
	-- Start in Youngstown Yard
	print("Start in the Youngstown Yard Block, heading east - setup occupancy flags for start");
	SetEvent(1, BLOCK_OCCUPANCY_EVENT, YOUNGSTOWN_YARD_BLOCK, OCC, 0);	-- set next block occupancy
	SetOccupancy(YOUNGSTOWN_YARD_BLOCK, 1);	-- set occupancy flag
--]=]
	--[=[
	-- Start in McKees Rocks Yard
	print("Start in the McKees Rocks Yard Block, heading west - setup occupancy flags for start");
	SetEvent(1, BLOCK_OCCUPANCY_EVENT, MCKEES_ROCKS_YARD_BLOCK, OCC, 0);	-- set next block occupancy
	SetOccupancy(MCKEES_ROCKS_YARD_BLOCK, 1);	-- set occupancy flag
--]=]	
	--
	print([[SetEvent() calls simulate a tag detection (TAG_EVENT) to the Layout4 APB Master.lua" script]]);
	return true;		-- false=setup failed, true=setup succeeded
end;
--[[---------------------------------------------------------------------------------------]]
function loop(Engine, TIU)
-- Always call Sleep(X) at least once in this function if it returns true;
print("loop() Running Westbound at ", RunTime(), " seconds");
local res, MyDirection;
--[=[
MyDirection = WB;
if (Layout4.LLLoop == true) then
	-- using events, cause "Layout4 APB Master.lua" to run a simulated train around the layout
	--
	-- This script always start in ALIQUIPPA_BLOCK going westbound in loop configuration using the BALLOON loop
	--
	-- this runs a train by generating a TAG_EVENT just as if a tag passed over a tag reader
	--  SetEvent(1, TAG_EVENT, detector, reader, 1 for EngineNo or 0 for Caboose)
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, WEST_ALIQUIPPA_DETECTOR, WEST_ALIQUIPPA_READER, 1);	-- set next block occupancy
		SetOccupancy(WEST_ALIQUIPPA_BLOCK, 1);
	if (type(res) ==  "nil") then
		print("SetEvent() returned nil : invalid destination Program Control number - Layout4 APB Master.lua not running");
		return Stop("DONE");
		end;
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, WEST_ALIQUIPPA_DETECTOR, WEST_ALIQUIPPA_READER, 0);	-- clear current block occupancy
		ClearOccupancy(ALIQUIPPA_BLOCK, 1);		
	-----------------------------------------
	-- repeat for each block around the layout
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, MONACA_EAST_DETECTOR, MONACA_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(MONACA_BLOCK, 1);
	if (type(res) ==  "nil") then
		print("SetEvent() returned nil : invalid destination Program Control number - Layout4 APB Master.lua not running");
		return Stop("DONE");
		end;
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, MONACA_EAST_DETECTOR, MONACA_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(WEST_ALIQUIPPA_BLOCK, 1);	
	-----------------------------------------
	-- repeat for each block around the layout
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, MONACA_WEST_DETECTOR, MONACA_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(FALLSTON_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, MONACA_WEST_DETECTOR, MONACA_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(MONACA_BLOCK, 1);
	-----------------------------------------
	--
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, FALLSTON_DETECTOR, FALLSTON_READER, 1);	-- set next block occupancy
		SetOccupancy(BEAVER_FALLS_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, FALLSTON_DETECTOR, FALLSTON_READER, 0);	-- clear current block occupancy
		ClearOccupancy(FALLSTON_BLOCK, 1);
	-----------------------------------------
	--
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, COLLEGE_EAST_DETECTOR, COLLEGE_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(COLLEGE_THRU_TRACK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, COLLEGE_EAST_DETECTOR, COLLEGE_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(BEAVER_FALLS_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, COLLEGE_WEST_DETECTOR, COLLEGE_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(NEW_CASTLE_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, COLLEGE_WEST_DETECTOR, COLLEGE_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(COLLEGE_THRU_TRACK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;		-- Split NEW_CASTLE_BLOCK
	res = SetEvent(1, TAG_EVENT, LOWELLVILLE_DETECTOR, LOWELLVILLE_READER, 1);	-- set next block occupancy
		SetOccupancy(LOWELLVILLE_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, LOWELLVILLE_DETECTOR, LOWELLVILLE_READER, 0);	-- clear current block occupancy
		ClearOccupancy(NEW_CASTLE_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;		-- Split NEW_CASTLE_BLOCK
	res = SetEvent(1, TAG_EVENT, STRUTHERS_EAST_DETECTOR, STRUTHERS_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(STRUTHERS_THRU_TRACK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, STRUTHERS_EAST_DETECTOR, STRUTHERS_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(LOWELLVILLE_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, STRUTHERS_WEST_DETECTOR, STRUTHERS_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(YOUNGSTOWN_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, STRUTHERS_WEST_DETECTOR, STRUTHERS_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(STRUTHERS_THRU_TRACK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, YOUNGSTOWN_YARD_DETECTOR, YOUNGSTOWN_YARD_READER, 1);	-- set next block occupancy
		SetOccupancy(LIONEL_IVES_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, YOUNGSTOWN_YARD_DETECTOR, YOUNGSTOWN_YARD_READER, 0);	-- clear current block occupancy
		ClearOccupancy(YOUNGSTOWN_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, MCKEES_ROCKS_YARD_DETECTOR, MCKEES_ROCKS_YARD_READER, 1);	-- set next block occupancy
		SetOccupancy(MCKEES_ROCKS_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, MCKEES_ROCKS_YARD_DETECTOR, MCKEES_ROCKS_YARD_READER, 0);	-- clear current block occupancy
		ClearOccupancy(LIONEL_IVES_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_EAST_DETECTOR, ALIQUIPPA_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(J_L_THRU_TRACK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_EAST_DETECTOR, ALIQUIPPA_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(MCKEES_ROCKS_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_WEST_DETECTOR, ALIQUIPPA_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(ALIQUIPPA_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_WEST_DETECTOR, ALIQUIPPA_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(J_L_THRU_TRACK, 1);
	--
	end;
--]=]
---[=[
if (Layout4.LLLoop == false) then
	-- using events, cause "Layout4 APB Master.lua" to run a simulated train around the layout
	--
	-- This script always start in ALIQUIPPA_BLOCK going westbound to Youngstown in Point-to-Point configuration
	-- Then it switches to eastbound to McKees Rocks, then switches back toward Aliquippa.
	-- This repeats.
	--
	-- this runs a train by generating a TAG_EVENT just as if a tag passed over a tag reader
	--  SetEvent(1, TAG_EVENT, detector, reader, 1 for EngineNo or 0 for Caboose)
	--

	-----------------------------------------
	-- Now reverse direction and run the length of the layout to McKees Rocks
	MyDirection = EB;
	--
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, YOUNGSTOWN_YARD_DETECTOR, YOUNGSTOWN_YARD_READER, 1);	-- set next block occupancy
		SetOccupancy(YOUNGSTOWN_BLOCK, 1);
	if (type(res) ==  "nil") then
		print("Layout4 APB Master.lua not running in PC#1");
		return Stop("DONE");
		end;		
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, YOUNGSTOWN_YARD_DETECTOR, YOUNGSTOWN_YARD_READER, 0);	-- clear current block occupancy
		ClearOccupancy(YOUNGSTOWN_YARD_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, STRUTHERS_WEST_DETECTOR, STRUTHERS_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(STRUTHERS_THRU_TRACK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, STRUTHERS_WEST_DETECTOR, STRUTHERS_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(YOUNGSTOWN_BLOCK, 1);
	--			
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, STRUTHERS_EAST_DETECTOR, STRUTHERS_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(LOWELLVILLE_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, STRUTHERS_EAST_DETECTOR, STRUTHERS_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(STRUTHERS_THRU_TRACK, 1);
	--			
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, LOWELLVILLE_DETECTOR, LOWELLVILLE_READER, 1);	-- set next block occupancy
		SetOccupancy(NEW_CASTLE_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, LOWELLVILLE_DETECTOR, LOWELLVILLE_READER, 0);	-- clear current block occupancy
		ClearOccupancy(LOWELLVILLE_BLOCK, 1);
	--	
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, COLLEGE_WEST_DETECTOR, COLLEGE_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(COLLEGE_THRU_TRACK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, COLLEGE_WEST_DETECTOR, COLLEGE_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(NEW_CASTLE_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, COLLEGE_EAST_DETECTOR, COLLEGE_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(BEAVER_FALLS_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, COLLEGE_EAST_DETECTOR, COLLEGE_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(COLLEGE_THRU_TRACK, 1);
	--
	-----------------------------------------
	--
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, FALLSTON_DETECTOR, FALLSTON_READER, 1);	-- set next block occupancy
		SetOccupancy(FALLSTON_BLOCK , 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, FALLSTON_DETECTOR, FALLSTON_READER, 0);	-- clear current block occupancy
		ClearOccupancy(BEAVER_FALLS_BLOCK, 1);
	-----------------------------------------
	--
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, MONACA_WEST_DETECTOR, MONACA_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(MONACA_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, MONACA_WEST_DETECTOR, MONACA_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(FALLSTON_BLOCK, 1);
	-----------------------------------------
	--
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, MONACA_EAST_DETECTOR, MONACA_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(WEST_ALIQUIPPA_BLOCK , 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, MONACA_EAST_DETECTOR, MONACA_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(MONACA_BLOCK, 1);
	--		
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, WEST_ALIQUIPPA_DETECTOR, WEST_ALIQUIPPA_READER, 1);	-- set next block occupancy
		SetOccupancy(ALIQUIPPA_BLOCK , 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, WEST_ALIQUIPPA_DETECTOR, WEST_ALIQUIPPA_READER, 0);	-- clear current block occupancy
		ClearOccupancy(WEST_ALIQUIPPA_BLOCK, 1);	
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_WEST_DETECTOR, ALIQUIPPA_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(J_L_THRU_TRACK , 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_WEST_DETECTOR, ALIQUIPPA_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(ALIQUIPPA_BLOCK, 1);
	--	
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_EAST_DETECTOR, ALIQUIPPA_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(MCKEES_ROCKS_BLOCK , 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_EAST_DETECTOR, ALIQUIPPA_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(J_L_THRU_TRACK, 1);
	--	
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, MCKEES_ROCKS_YARD_DETECTOR, MCKEES_ROCKS_YARD_READER, 1);	-- set next block occupancy
		SetOccupancy(MCKEES_ROCKS_YARD_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, MCKEES_ROCKS_YARD_DETECTOR, MCKEES_ROCKS_YARD_READER, 0);	-- clear current block occupancy
		ClearOccupancy(MCKEES_ROCKS_BLOCK, 1);
	--	
	-- Now reverse direction again and run to Aliquippa Block
	MyDirection = WB;
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, MCKEES_ROCKS_YARD_DETECTOR, MCKEES_ROCKS_YARD_READER, 1);	-- set next block occupancy
		SetOccupancy(MCKEES_ROCKS_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, MCKEES_ROCKS_YARD_DETECTOR, MCKEES_ROCKS_YARD_READER, 0);	-- clear current block occupancy
		ClearOccupancy(MCKEES_ROCKS_YARD_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_EAST_DETECTOR, ALIQUIPPA_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(J_L_THRU_TRACK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_EAST_DETECTOR, ALIQUIPPA_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(MCKEES_ROCKS_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_WEST_DETECTOR, ALIQUIPPA_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(ALIQUIPPA_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_WEST_DETECTOR, ALIQUIPPA_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(J_L_THRU_TRACK, 1);
	--	
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, WEST_ALIQUIPPA_DETECTOR, WEST_ALIQUIPPA_READER, 1);	-- set next block occupancy
		SetOccupancy(WEST_ALIQUIPPA_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, WEST_ALIQUIPPA_DETECTOR, WEST_ALIQUIPPA_READER, 0);	-- clear current block occupancy
		ClearOccupancy(ALIQUIPPA_BLOCK, 1);		
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, MONACA_EAST_DETECTOR, MONACA_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(MONACA_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, MONACA_EAST_DETECTOR, MONACA_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(WEST_ALIQUIPPA_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, MONACA_WEST_DETECTOR, MONACA_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(FALLSTON_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, MONACA_WEST_DETECTOR, MONACA_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(MONACA_BLOCK, 1);
	-----------------------------------------
	--
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, FALLSTON_DETECTOR, FALLSTON_READER, 1);	-- set next block occupancy
		SetOccupancy(BEAVER_FALLS_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, FALLSTON_DETECTOR, FALLSTON_READER, 0);	-- clear current block occupancy
		ClearOccupancy(FALLSTON_BLOCK, 1);
	-----------------------------------------
	--
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, COLLEGE_EAST_DETECTOR, COLLEGE_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(COLLEGE_THRU_TRACK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, COLLEGE_EAST_DETECTOR, COLLEGE_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(BEAVER_FALLS_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, COLLEGE_WEST_DETECTOR, COLLEGE_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(NEW_CASTLE_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, COLLEGE_WEST_DETECTOR, COLLEGE_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(COLLEGE_THRU_TRACK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;		-- Split NEW_CASTLE_BLOCK
	res = SetEvent(1, TAG_EVENT, LOWELLVILLE_DETECTOR, LOWELLVILLE_READER, 1);	-- set next block occupancy
		SetOccupancy(LOWELLVILLE_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, LOWELLVILLE_DETECTOR, LOWELLVILLE_READER, 0);	-- clear current block occupancy
		ClearOccupancy(NEW_CASTLE_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;		-- Split NEW_CASTLE_BLOCK
	res = SetEvent(1, TAG_EVENT, STRUTHERS_EAST_DETECTOR, STRUTHERS_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(STRUTHERS_THRU_TRACK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, STRUTHERS_EAST_DETECTOR, STRUTHERS_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(LOWELLVILLE_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, STRUTHERS_WEST_DETECTOR, STRUTHERS_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(YOUNGSTOWN_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, STRUTHERS_WEST_DETECTOR, STRUTHERS_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(STRUTHERS_THRU_TRACK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, YOUNGSTOWN_YARD_DETECTOR, YOUNGSTOWN_YARD_READER, 1);	-- set next block occupancy
		SetOccupancy(YOUNGSTOWN_YARD_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, YOUNGSTOWN_YARD_DETECTOR, YOUNGSTOWN_YARD_READER, 0);	-- clear current block occupancy
		ClearOccupancy(YOUNGSTOWN_BLOCK, 1);
	--

	--	
	end
--]=]
--[=[
-- Short Test from YOUNGSTOWN_YARD_BLOCK to LOWELLVILLE_BLOCK
	MyDirection = EB;
	--
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, YOUNGSTOWN_YARD_DETECTOR, YOUNGSTOWN_YARD_READER, 1);	-- set next block occupancy
		SetOccupancy(YOUNGSTOWN_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, YOUNGSTOWN_YARD_DETECTOR, YOUNGSTOWN_YARD_READER, 0);	-- clear current block occupancy
		ClearOccupancy(YOUNGSTOWN_YARD_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, STRUTHERS_WEST_DETECTOR, STRUTHERS_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(STRUTHERS_THRU_TRACK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, STRUTHERS_WEST_DETECTOR, STRUTHERS_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(YOUNGSTOWN_BLOCK, 1);
	--			
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, STRUTHERS_EAST_DETECTOR, STRUTHERS_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(LOWELLVILLE_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, STRUTHERS_EAST_DETECTOR, STRUTHERS_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(STRUTHERS_THRU_TRACK, 1);
	--	
	-- this test script crashes RTC here (don't care)
	--
	while (not PauseOn) do Sleep(1); end;
--]=]
--[=[
-- Short Test from MCKEES_ROCKS_YARD_BLOCK to ALIQUIPPA_BLOCK
	MyDirection = WB;

	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, MCKEES_ROCKS_YARD_DETECTOR, MCKEES_ROCKS_YARD_READER, 1);	-- set next block occupancy
		SetOccupancy(MCKEES_ROCKS_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, MCKEES_ROCKS_YARD_DETECTOR, MCKEES_ROCKS_YARD_READER, 0);	-- clear current block occupancy
		ClearOccupancy(MCKEES_ROCKS_YARD_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_EAST_DETECTOR, ALIQUIPPA_EAST_READER, 1);	-- set next block occupancy
		SetOccupancy(J_L_THRU_TRACK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_EAST_DETECTOR, ALIQUIPPA_EAST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(MCKEES_ROCKS_BLOCK, 1);
	--
	-----------------------------------------
	Sleep(StepTime);
	while (PauseOn) do Sleep(1); end;
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_WEST_DETECTOR, ALIQUIPPA_WEST_READER, 1);	-- set next block occupancy
		SetOccupancy(ALIQUIPPA_BLOCK, 1);
	Sleep(StepTime);
	res = SetEvent(1, TAG_EVENT, ALIQUIPPA_WEST_DETECTOR, ALIQUIPPA_WEST_READER, 0);	-- clear current block occupancy
		ClearOccupancy(J_L_THRU_TRACK, 1);
	--
--]=]	
	-----------------------------------------
	--print("Paused at end of test");
	--while (not PauseOn) do Sleep(1); end;
	
return true;		-- all of the code runs in the loop()
end;
--[[---------------------------------------------------------------------------------------]]

function cleanup(Engine, TIU)
	-- this function is called once when the user presses the [STOP] button or the Stop() function is called
	print("cleanup() Running");
	if (ErrCount == 0) then
		print("No errors");
		else
		print(ErrCount .. " Error(s)");
		end;	
	return true;		-- false=cleanup failed, true=cleanup succeeded
	end
--[[---------------------------------------------------------------------------------------]]

function PZ()
	if (PauseOn) then
		print("...Resumed");
		PauseOn = false;
		else
		print("Paused...");
		PauseOn = true;
		end;
	return true;
end
Function01Name, Function01Label = PZ, "Pause/Resume";
--[[---------------------------------------------------------------------------------------]]
function ClearButton(Eng, TIU)
print("Clear Occupancy Flags");
-- clear occupancy flags
local x;
for x = FIRST_BLOCK, LAST_BLOCK do
	OverrideOccupancy(x, 0);
	end;
print("Occupancy Flags cleared");
return true;
end
Function02Name, Function02Label = ClearButton, "Clear Flags";
--[[---------------------------------------------------------------------------------------]]